@@ -1,5 +1,15 @@
 package SQL::Statement::Operation;
 
+######################################################################
+#
+# This module is copyright (c), 2009-2016 by Jens Rehsack.
+# All rights reserved.
+#
+# It may be freely distributed under the same terms as Perl itself.
+# See below for help and copyright information (search for SYNOPSIS).
+#
+######################################################################
+
 use strict;
 use warnings FATAL => "all";
 
@@ -8,7 +18,7 @@ use Carp ();
 
 use SQL::Statement::Term ();
 
-our $VERSION = '1.406_002';
+our $VERSION = '1.408_001';
 
 @ISA = qw(SQL::Statement::Term);
 
@@ -186,7 +196,13 @@ left and right operand.
 
 =cut
 
-sub operate($) { return $_[0]->{LEFT}->value( $_[1] ) && $_[0]->{RIGHT}->value( $_[1] ); }
+sub operate($)
+{
+    my $left  = $_[0]->{LEFT}->value( $_[1] );
+    my $right = $_[0]->{RIGHT}->value( $_[1] );
+
+    return $left && $right;
+}
 
 package SQL::Statement::Operation::Or;
 
@@ -227,7 +243,13 @@ left and right operand.
 
 =cut
 
-sub operate($) { return $_[0]->{LEFT}->value( $_[1] ) || $_[0]->{RIGHT}->value( $_[1] ); }
+sub operate($)
+{
+    my $left  = $_[0]->{LEFT}->value( $_[1] );
+    my $right = $_[0]->{RIGHT}->value( $_[1] );
+
+    return $left || $right;
+}
 
 package SQL::Statement::Operation::Is;
 
@@ -1035,7 +1057,7 @@ sub regexp($)
 
 =head1 AUTHOR AND COPYRIGHT
 
-Copyright (c) 2009,2010 by Jens Rehsack: rehsackATcpan.org
+Copyright (c) 2009,2016 by Jens Rehsack: rehsackATcpan.org
 
 All rights reserved.
 
